@@ -1,8 +1,9 @@
 /* deborphan - Find orphaned libraries on a Debian system.
    Copyright (C) 2000, 2001, 2002, 2003 Cris van Pelt
    Copyright (C) 2003, 2004 Peter Palfrader
+   Copyright (C) 2008, 2009 Carsten Hey
 
-   $Id: deborphan.c 511 2005-03-16 14:52:39Z weasel $
+   $Id: deborphan.c 756 2009-02-19 08:10:54Z carsten-guest $
 
    Distributed under the terms of the Artistic License.
 */
@@ -70,16 +71,20 @@ main(int argc, char *argv[])
 #endif
     pkg_info *package, *this;
     int i, argind;
-    int exclude_list_cnt = 0;
-    int exclude_list_max = 0;
+    size_t exclude_list_cnt = 0;
+    size_t exclude_list_max = 0;
     dep *exclude_list = NULL;
 
+    /*@unused@*/ /* Actually it is used but splint does not recognise this. */
     struct option longopts[] = {
 	{"version", 0, 0, 'v'},
 	{"help", 0, 0, 'h'},
 	{"status-file", 1, 0, 'f'},
 	{"show-deps", 0, 0, 'd'},
+	{"show-deps-pristine", 0, 0, 'd'},
 	{"nice-mode", 0, 0, 'n'},
+	{"ignore-recommends", 0, 0, 61},
+	{"ignore-suggests", 0, 0, 62},
 	{"all-packages", 0, 0, 'a'},
 	{"priority", 1, 0, 'p'},
 	{"show-section", 0, 0, 's'},
@@ -93,27 +98,44 @@ main(int argc, char *argv[])
 	{"list-keep", 0, 0, 'L'},
 	{"zero-keep", 0, 0, 'Z'},
 	{"guess-dev", 0, 0, 1},
+	{"no-guess-dev", 0, 0, 31},
 	{"guess-perl", 0, 0, 2},
+	{"no-guess-perl", 0, 0, 32},
 	{"guess-section", 0, 0, 3},
+	{"no-guess-section", 0, 0, 33},
 	{"guess-all", 0, 0, 4},
+	{"no-guess-all", 0, 0, 34},
 	{"guess-debug", 0, 0, 5},
+	{"no-guess-debug", 0, 0, 35},
 #ifdef DEBFOSTER_KEEP
-	{"df-keep", 0, 0, 6},
+        {"df-keep", 0, 0, 6},
 #endif
 	{"guess-only", 0, 0, 7},
 #ifdef DEBFOSTER_KEEP
-	{"no-df-keep", 0, 0, 8},
+        {"no-df-keep", 0, 0, 8},
 #endif
 	{"guess-pike", 0, 0, 9},
+	{"no-guess-pike", 0, 0, 39},
 	{"guess-python", 0, 0, 10},
+	{"no-guess-python", 0, 0, 40},
 	{"guess-ruby", 0, 0, 11},
+	{"no-guess-ruby", 0, 0, 41},
 	{"guess-interpreters", 0, 0, 12},
+	{"no-guess-interpreters", 0, 0, 42},
 	{"guess-dummy", 0, 0, 13},
+	{"no-guess-dummy", 0, 0, 43},
 	{"guess-common", 0, 0, 14},
+	{"no-guess-common", 0, 0, 44},
 	{"guess-data", 0, 0, 15},
+	{"no-guess-data", 0, 0, 45},
 	{"guess-doc", 0, 0, 16},
+	{"no-guess-doc", 0, 0, 46},
 	{"find-config", 0, 0, 17},
 	{"libdevel", 0, 0, 18},
+	{"guess-mono", 0, 0, 19},
+	{"no-guess-mono", 0, 0, 49},
+	{"guess-kernel", 0, 0, 20},
+	{"no-guess-kernel", 0, 0, 50},
 	{"exclude", 1, 0, 'e'},
 	{0, 0, 0, 0}
     };
@@ -152,6 +174,12 @@ main(int argc, char *argv[])
 	case 'n':
 	    options[NICE_MODE] = 1;
 	    break;
+	case 61:
+	    options[IGNORE_RECOMMENDS] = 1;
+	    break;
+	case 62:
+	    options[IGNORE_SUGGESTS] = 1;
+	    break;
 	case 'a':
 	    options[ALL_PACKAGES] = 1;
 #ifdef ALL_PACKAGES_IMPLY_SECTION
@@ -200,55 +228,94 @@ main(int argc, char *argv[])
 	case 1:
 	    guess_set(GUESS_DEV);
 	    break;
+	case 31:
+	    guess_clr(GUESS_DEV);
+	    break;
 	case 2:
 	    guess_set(GUESS_PERL);
 	    break;
+	case 32:
+	    guess_clr(GUESS_PERL);
+	    break;
 	case 3:
 	    guess_set(GUESS_SECTION);
 	    break;
+	case 33:
+	    guess_clr(GUESS_SECTION);
+	    break;
 	case 4:
 	    guess_set(GUESS_ALL);
 	    break;
+	case 34:
+	    guess_clr(GUESS_ALL);
+	    break;
 	case 5:
 	    guess_set(GUESS_DEBUG);
 	    break;
-#ifdef DEBFOSTER_KEEP
-	case 6:
-	    options[NO_DEBFOSTER] = 0;
+	case 35:
+	    guess_clr(GUESS_DEBUG);
 	    break;
+#ifdef DEBFOSTER_KEEP
+        case 6:
+            options[NO_DEBFOSTER] = 0;
+            break;
 #endif
 	case 7:
 	    options[GUESS_ONLY] = 1;
 	    break;
 #ifdef DEBFOSTER_KEEP
-	case 8:
-	    options[NO_DEBFOSTER] = 1;
-	    break;
+        case 8:
+            options[NO_DEBFOSTER] = 1;
+            break;
 #endif
 	case 9:
 	    guess_set(GUESS_PIKE);
 	    break;
+	case 39:
+	    guess_clr(GUESS_PIKE);
+	    break;
 	case 10:
 	    guess_set(GUESS_PYTHON);
 	    break;
+	case 40:
+	    guess_clr(GUESS_PYTHON);
+	    break;
 	case 11:
 	    guess_set(GUESS_RUBY);
 	    break;
+	case 41:
+	    guess_clr(GUESS_RUBY);
+	    break;
 	case 12:
 	    guess_set(GUESS_IP);
 	    break;
+	case 42:
+	    guess_clr(GUESS_IP);
+	    break;
 	case 13:
 	    guess_set(GUESS_DUMMY);
 	    break;
+	case 43:
+	    guess_clr(GUESS_DUMMY);
+	    break;
 	case 14:
 	    guess_set(GUESS_COMMON);
 	    break;
+	case 44:
+	    guess_clr(GUESS_COMMON);
+	    break;
 	case 15:
 	    guess_set(GUESS_DATA);
 	    break;
+	case 45:
+	    guess_clr(GUESS_DATA);
+	    break;
 	case 16:
 	    guess_set(GUESS_DOC);
 	    break;
+	case 46:
+	    guess_clr(GUESS_DOC);
+	    break;
 	case 17:
 	    options[FIND_CONFIG] = 1;
 	    options[ALL_PACKAGES] = 1;
@@ -256,6 +323,18 @@ main(int argc, char *argv[])
 	case 18:
 	    options[SEARCH_LIBDEVEL] = 1;
 	    break;
+	case 19:
+	    guess_set(GUESS_MONO);
+	    break;
+	case 49:
+	    guess_clr(GUESS_MONO);
+	    break;
+	case 20:
+	    guess_set(GUESS_KERNEL);
+	    break;
+	case 50:
+	    guess_clr(GUESS_KERNEL);
+	    break;
 	case 'e':
 	    while ( optarg ) {
 		    char *c_ptr;
@@ -281,7 +360,6 @@ main(int argc, char *argv[])
 	case '?':
 	    print_usage(stderr);
 	    exit(EXIT_FAILURE);
-	    break;
 	}
     }
 #ifdef DEFAULT_NICE		/* Invert the value of nice_mode */
@@ -356,6 +434,7 @@ main(int argc, char *argv[])
 	    switch (delkeep(kfile, args)) {
 	    case -1:
 		error(EXIT_FAILURE, errno, "%s", kfile);
+                break; /* make splint happy */
 	    case 1:
 		error(EXIT_FAILURE, 0, "no packages removed.");
 	    }
@@ -381,7 +460,7 @@ main(int argc, char *argv[])
     */
 #ifdef DEBFOSTER_KEEP
     if (!options[NO_DEBFOSTER]) {
-	deb *dfkeep = readkeep(DEBFOSTER_KEEP);
+	dep *dfkeep = readkeep(DEBFOSTER_KEEP);
 
 	if (dfkeep) {
 	    dep *d = keep;
